<?php

/**
 * @file
 *
 * Contains \Drupal\isfield\Plugin\field\formatter\ISFieldVideoFormatter.
 */
namespace Drupal\isfield\Plugin\field\formatter;
 
// FormatterBase class.
use Drupal\field\Plugin\Type\Formatter\FormatterBase;
// Fieldinterface
use Drupal\Core\Entity\Field\FieldInterface;

/**
 * Plugin implementation of the 'isfield_video' formatter
 *
 * @FieldFormatter(
 *   id = "isfield_video",
 *   label = @Translation("ISField video"),
 *   field_types = {
 *     "text",
 *     "text_long",
 *     "text_with_summary",
 *     "link"
 *   },
 *   settings = {
 *     "dimensions" = "480x360"
 *   }
 * )
 */
class ISFieldVideoFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, array &$form_state) {
    $element = array();

    $dimensions = \Drupal::config('isfield.settings')->get('video_dimensions');
    foreach ($dimensions as $key => $value) {
      if (!preg_match('/^\d+x\d+$/', $value)) {
        unset($dimensions[$key]);
      }
    }

    $element['dimensions'] = array(
      '#title' => t('Dimensions'),
      '#type' => 'select',
      '#default_value' => $this->getSetting('dimensions'),
      '#options' => array_combine($dimensions, $dimensions),
      '#description' => t('The above list of predefined dimensions could be modified in the <a href="@url">settings page</a>.', array(
        '@url' => url('admin/config/media/isfield'),
      )),
    );

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = array();
    $summary[] = t('Dimensions: @dimensions', array('@dimensions' => $this->getSetting('dimensions')));
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldInterface $items) {
    $elements = array();
    $options = array();

    $dimensions = $this->getSetting('dimensions');
    if ($dimensions) {
      list($options['width'], $options['height']) = explode('x', $dimensions);
    }

    foreach ($items as $delta => $item) {
      $text = $item->getFieldDefinition()->getFieldType() == 'link' ? $item->url : $item->value;
      if (!$wrapper = isfield_get_media_wrapper($text)) {
        continue;
      }
      $elements[$delta] = array('#markup' => $wrapper->player($options));
    }

    return $elements;
  }
}
